==> zio-aws-proton_2.13-7.21.15.11-sources.jar: zio/aws/proton/model/package.scala <==
package zio.aws.proton
import zio.aws.proton.model.primitives.{TagKey, DeploymentId}
import zio.prelude.Subtype
import java.time.Instant
import zio.aws.proton.model.primitives.RepositoryId.Type
package object model {
  import scala.jdk.CollectionConverters._
  object primitives {
    object Arn extends Subtype[String]
    type Arn = zio.aws.proton.model.primitives.Arn.Type
    object AwsAccountId extends Subtype[String]
    type AwsAccountId = zio.aws.proton.model.primitives.AwsAccountId.Type
    object ClientToken extends Subtype[String]
    type ClientToken = zio.aws.proton.model.primitives.ClientToken.Type
    object ComponentArn extends Subtype[String]
    type ComponentArn = zio.aws.proton.model.primitives.ComponentArn.Type
    object DeploymentArn extends Subtype[String]
    type DeploymentArn = zio.aws.proton.model.primitives.DeploymentArn.Type
    object DeploymentId extends Subtype[String]
    type DeploymentId = zio.aws.proton.model.primitives.DeploymentId.Type
    object Description extends Subtype[String]
    type Description = zio.aws.proton.model.primitives.Description.Type
    object DisplayName extends Subtype[String]
    type DisplayName = zio.aws.proton.model.primitives.DisplayName.Type
    object EmptyNextToken extends Subtype[String]
    type EmptyNextToken = zio.aws.proton.model.primitives.EmptyNextToken.Type
    object EnvironmentAccountConnectionArn extends Subtype[String]
    type EnvironmentAccountConnectionArn =
      zio.aws.proton.model.primitives.EnvironmentAccountConnectionArn.Type
    object EnvironmentAccountConnectionId extends Subtype[String]
    type EnvironmentAccountConnectionId =
      zio.aws.proton.model.primitives.EnvironmentAccountConnectionId.Type
    object EnvironmentArn extends Subtype[String]
    type EnvironmentArn = zio.aws.proton.model.primitives.EnvironmentArn.Type
    object EnvironmentTemplateArn extends Subtype[String]
    type EnvironmentTemplateArn =
      zio.aws.proton.model.primitives.EnvironmentTemplateArn.Type
    object EnvironmentTemplateVersionArn extends Subtype[String]
    type EnvironmentTemplateVersionArn =
      zio.aws.proton.model.primitives.EnvironmentTemplateVersionArn.Type
    object FullTemplateVersionNumber extends Subtype[String]
    type FullTemplateVersionNumber =
      zio.aws.proton.model.primitives.FullTemplateVersionNumber.Type
    object GitBranchName extends Subtype[String]
    type GitBranchName = zio.aws.proton.model.primitives.GitBranchName.Type
    type Integer = Int
    object ListServiceInstancesFilterValue extends Subtype[String]
    type ListServiceInstancesFilterValue =
      zio.aws.proton.model.primitives.ListServiceInstancesFilterValue.Type
    object MaxPageResults extends Subtype[Int]
    type MaxPageResults = zio.aws.proton.model.primitives.MaxPageResults.Type
    object NextToken extends Subtype[String]
    type NextToken = zio.aws.proton.model.primitives.NextToken.Type
    object NotifyResourceDeploymentStatusChangeInputStatusMessageString
        extends Subtype[String]
    type NotifyResourceDeploymentStatusChangeInputStatusMessageString =
      zio.aws.proton.model.primitives.NotifyResourceDeploymentStatusChangeInputStatusMessageString.Type
    object OpsFilePath extends Subtype[String]
    type OpsFilePath = zio.aws.proton.model.primitives.OpsFilePath.Type
    object OutputKey extends Subtype[String]
    type OutputKey = zio.aws.proton.model.primitives.OutputKey.Type
    object OutputValueString extends Subtype[String]
    type OutputValueString =
      zio.aws.proton.model.primitives.OutputValueString.Type
    object ProvisionedResourceIdentifier extends Subtype[String]
    type ProvisionedResourceIdentifier =
      zio.aws.proton.model.primitives.ProvisionedResourceIdentifier.Type
    object ProvisionedResourceName extends Subtype[String]
    type ProvisionedResourceName =
      zio.aws.proton.model.primitives.ProvisionedResourceName.Type
    object RepositoryArn extends Subtype[String]
    type RepositoryArn = zio.aws.proton.model.primitives.RepositoryArn.Type
    object RepositoryId extends Subtype[String]
    type RepositoryId = zio.aws.proton.model.primitives.RepositoryId.Type
    object RepositoryName extends Subtype[String]
    type RepositoryName = zio.aws.proton.model.primitives.RepositoryName.Type
    object ResourceName extends Subtype[String]
    type ResourceName = zio.aws.proton.model.primitives.ResourceName.Type
    object ResourceNameOrEmpty extends Subtype[String]
    type ResourceNameOrEmpty =
      zio.aws.proton.model.primitives.ResourceNameOrEmpty.Type
    object RoleArn extends Subtype[String]
    type RoleArn = zio.aws.proton.model.primitives.RoleArn.Type
    object RoleArnOrEmptyString extends Subtype[String]
    type RoleArnOrEmptyString =
      zio.aws.proton.model.primitives.RoleArnOrEmptyString.Type
    object S3Bucket extends Subtype[String]
    type S3Bucket = zio.aws.proton.model.primitives.S3Bucket.Type
    object S3Key extends Subtype[String]
    type S3Key = zio.aws.proton.model.primitives.S3Key.Type
    object SHA extends Subtype[String]
    type SHA = zio.aws.proton.model.primitives.SHA.Type
    object ServiceArn extends Subtype[String]
    type ServiceArn = zio.aws.proton.model.primitives.ServiceArn.Type
    object ServiceInstanceArn extends Subtype[String]
    type ServiceInstanceArn =
      zio.aws.proton.model.primitives.ServiceInstanceArn.Type
    object ServiceTemplateArn extends Subtype[String]
    type ServiceTemplateArn =
      zio.aws.proton.model.primitives.ServiceTemplateArn.Type
    object ServiceTemplateVersionArn extends Subtype[String]
    type ServiceTemplateVersionArn =
      zio.aws.proton.model.primitives.ServiceTemplateVersionArn.Type
    object SpecContents extends Subtype[String]
    type SpecContents = zio.aws.proton.model.primitives.SpecContents.Type
    object StatusMessage extends Subtype[String]
    type StatusMessage = zio.aws.proton.model.primitives.StatusMessage.Type
    object Subdirectory extends Subtype[String]
    type Subdirectory = zio.aws.proton.model.primitives.Subdirectory.Type
    object TagKey extends Subtype[String]
    type TagKey = zio.aws.proton.model.primitives.TagKey.Type
    object TagValue extends Subtype[String]
    type TagValue = zio.aws.proton.model.primitives.TagValue.Type
    object TemplateFileContents extends Subtype[String]
    type TemplateFileContents =
      zio.aws.proton.model.primitives.TemplateFileContents.Type
    object TemplateManifestContents extends Subtype[String]
    type TemplateManifestContents =
      zio.aws.proton.model.primitives.TemplateManifestContents.Type
    object TemplateSchema extends Subtype[String]
    type TemplateSchema = zio.aws.proton.model.primitives.TemplateSchema.Type
    object TemplateVersionPart extends Subtype[String]
    type TemplateVersionPart =
      zio.aws.proton.model.primitives.TemplateVersionPart.Type
    object Timestamp extends Subtype[Instant]
    type Timestamp = zio.aws.proton.model.primitives.Timestamp.Type
  }
  type CompatibleEnvironmentTemplateInputList =
    List[zio.aws.proton.model.CompatibleEnvironmentTemplateInput]
  type CompatibleEnvironmentTemplateList =
    List[zio.aws.proton.model.CompatibleEnvironmentTemplate]
  type ComponentDeploymentIdList = List[DeploymentId]
  type ComponentSummaryList = List[zio.aws.proton.model.ComponentSummary]
  type DeploymentSummaryList = List[zio.aws.proton.model.DeploymentSummary]
  type EnvironmentAccountConnectionStatusList =
    List[zio.aws.proton.model.EnvironmentAccountConnectionStatus]
  type EnvironmentAccountConnectionSummaryList =
    List[zio.aws.proton.model.EnvironmentAccountConnectionSummary]
  type EnvironmentSummaryList = List[zio.aws.proton.model.EnvironmentSummary]
  type EnvironmentTemplateFilterList =
    List[zio.aws.proton.model.EnvironmentTemplateFilter]
  type EnvironmentTemplateSummaryList =
    List[zio.aws.proton.model.EnvironmentTemplateSummary]
  type EnvironmentTemplateVersionSummaryList =
    List[zio.aws.proton.model.EnvironmentTemplateVersionSummary]
  type LatestSyncBlockers = List[zio.aws.proton.model.SyncBlocker]
  type ListServiceInstancesFilterList =
    List[zio.aws.proton.model.ListServiceInstancesFilter]
  type NotifyResourceDeploymentStatusChangeInputOutputsList =
    List[zio.aws.proton.model.Output]
  type OutputsList = List[zio.aws.proton.model.Output]
  type ProvisionedResourceList = List[zio.aws.proton.model.ProvisionedResource]
  type RepositorySummaryList = List[zio.aws.proton.model.RepositorySummary]
  type RepositorySyncDefinitionList =
    List[zio.aws.proton.model.RepositorySyncDefinition]
  type RepositorySyncEvents = List[zio.aws.proton.model.RepositorySyncEvent]
  type ResourceSyncEvents = List[zio.aws.proton.model.ResourceSyncEvent]
  type ServiceInstanceSummaryList =
    List[zio.aws.proton.model.ServiceInstanceSummary]
  type ServiceSummaryList = List[zio.aws.proton.model.ServiceSummary]
  type ServiceTemplateSummaryList =
    List[zio.aws.proton.model.ServiceTemplateSummary]
  type ServiceTemplateSupportedComponentSourceInputList =
    List[zio.aws.proton.model.ServiceTemplateSupportedComponentSourceType]
  type ServiceTemplateVersionSummaryList =
    List[zio.aws.proton.model.ServiceTemplateVersionSummary]
  type SyncBlockerContexts = List[zio.aws.proton.model.SyncBlockerContext]
  type TagKeyList = List[TagKey]
  type TagList = List[zio.aws.proton.model.Tag]
}

==> zio-aws-proton_3-6.20.69.2-sources.jar: zio/aws/proton/model/package.scala <==
package zio.aws.proton
import zio.aws.proton.model.primitives.TagKey
import zio.prelude.Subtype
import java.time.Instant
import zio.aws.proton.model.primitives.RepositoryId.Type
package object model {
  import scala.jdk.CollectionConverters.*
  object primitives {
    object Arn extends Subtype[String]
    type Arn = zio.aws.proton.model.primitives.Arn.Type
    object AwsAccountId extends Subtype[String]
    type AwsAccountId = zio.aws.proton.model.primitives.AwsAccountId.Type
    object ClientToken extends Subtype[String]
    type ClientToken = zio.aws.proton.model.primitives.ClientToken.Type
    object ComponentArn extends Subtype[String]
    type ComponentArn = zio.aws.proton.model.primitives.ComponentArn.Type
    object DeploymentId extends Subtype[String]
    type DeploymentId = zio.aws.proton.model.primitives.DeploymentId.Type
    object Description extends Subtype[String]
    type Description = zio.aws.proton.model.primitives.Description.Type
    object DisplayName extends Subtype[String]
    type DisplayName = zio.aws.proton.model.primitives.DisplayName.Type
    object EmptyNextToken extends Subtype[String]
    type EmptyNextToken = zio.aws.proton.model.primitives.EmptyNextToken.Type
    object EnvironmentAccountConnectionArn extends Subtype[String]
    type EnvironmentAccountConnectionArn =
      zio.aws.proton.model.primitives.EnvironmentAccountConnectionArn.Type
    object EnvironmentAccountConnectionId extends Subtype[String]
    type EnvironmentAccountConnectionId =
      zio.aws.proton.model.primitives.EnvironmentAccountConnectionId.Type
    object EnvironmentArn extends Subtype[String]
    type EnvironmentArn = zio.aws.proton.model.primitives.EnvironmentArn.Type
    object EnvironmentTemplateArn extends Subtype[String]
    type EnvironmentTemplateArn =
      zio.aws.proton.model.primitives.EnvironmentTemplateArn.Type
    object EnvironmentTemplateVersionArn extends Subtype[String]
    type EnvironmentTemplateVersionArn =
      zio.aws.proton.model.primitives.EnvironmentTemplateVersionArn.Type
    object FullTemplateVersionNumber extends Subtype[String]
    type FullTemplateVersionNumber =
      zio.aws.proton.model.primitives.FullTemplateVersionNumber.Type
    object GitBranchName extends Subtype[String]
    type GitBranchName = zio.aws.proton.model.primitives.GitBranchName.Type
    type Integer = Int
    object ListServiceInstancesFilterValue extends Subtype[String]
    type ListServiceInstancesFilterValue =
      zio.aws.proton.model.primitives.ListServiceInstancesFilterValue.Type
    object MaxPageResults extends Subtype[Int]
    type MaxPageResults = zio.aws.proton.model.primitives.MaxPageResults.Type
    object NextToken extends Subtype[String]
    type NextToken = zio.aws.proton.model.primitives.NextToken.Type
    object NotifyResourceDeploymentStatusChangeInputStatusMessageString
        extends Subtype[String]
    type NotifyResourceDeploymentStatusChangeInputStatusMessageString =
      zio.aws.proton.model.primitives.NotifyResourceDeploymentStatusChangeInputStatusMessageString.Type
    object OpsFilePath extends Subtype[String]
    type OpsFilePath = zio.aws.proton.model.primitives.OpsFilePath.Type
    object OutputKey extends Subtype[String]
    type OutputKey = zio.aws.proton.model.primitives.OutputKey.Type
    object OutputValueString extends Subtype[String]
    type OutputValueString =
      zio.aws.proton.model.primitives.OutputValueString.Type
    object ProvisionedResourceIdentifier extends Subtype[String]
    type ProvisionedResourceIdentifier =
      zio.aws.proton.model.primitives.ProvisionedResourceIdentifier.Type
    object ProvisionedResourceName extends Subtype[String]
    type ProvisionedResourceName =
      zio.aws.proton.model.primitives.ProvisionedResourceName.Type
    object RepositoryArn extends Subtype[String]
    type RepositoryArn = zio.aws.proton.model.primitives.RepositoryArn.Type
    object RepositoryId extends Subtype[String]
    type RepositoryId = zio.aws.proton.model.primitives.RepositoryId.Type
    object RepositoryName extends Subtype[String]
    type RepositoryName = zio.aws.proton.model.primitives.RepositoryName.Type
    object ResourceName extends Subtype[String]
    type ResourceName = zio.aws.proton.model.primitives.ResourceName.Type
    object ResourceNameOrEmpty extends Subtype[String]
    type ResourceNameOrEmpty =
      zio.aws.proton.model.primitives.ResourceNameOrEmpty.Type
    object RoleArn extends Subtype[String]
    type RoleArn = zio.aws.proton.model.primitives.RoleArn.Type
    object RoleArnOrEmptyString extends Subtype[String]
    type RoleArnOrEmptyString =
      zio.aws.proton.model.primitives.RoleArnOrEmptyString.Type
    object S3Bucket extends Subtype[String]
    type S3Bucket = zio.aws.proton.model.primitives.S3Bucket.Type
    object S3Key extends Subtype[String]
    type S3Key = zio.aws.proton.model.primitives.S3Key.Type
    object SHA extends Subtype[String]
    type SHA = zio.aws.proton.model.primitives.SHA.Type
    object ServiceArn extends Subtype[String]
    type ServiceArn = zio.aws.proton.model.primitives.ServiceArn.Type
    object ServiceInstanceArn extends Subtype[String]
    type ServiceInstanceArn =
      zio.aws.proton.model.primitives.ServiceInstanceArn.Type
    object ServiceTemplateArn extends Subtype[String]
    type ServiceTemplateArn =
      zio.aws.proton.model.primitives.ServiceTemplateArn.Type
    object ServiceTemplateVersionArn extends Subtype[String]
    type ServiceTemplateVersionArn =
      zio.aws.proton.model.primitives.ServiceTemplateVersionArn.Type
    object SpecContents extends Subtype[String]
    type SpecContents = zio.aws.proton.model.primitives.SpecContents.Type
    object StatusMessage extends Subtype[String]
    type StatusMessage = zio.aws.proton.model.primitives.StatusMessage.Type
    object Subdirectory extends Subtype[String]
    type Subdirectory = zio.aws.proton.model.primitives.Subdirectory.Type
    object TagKey extends Subtype[String]
    type TagKey = zio.aws.proton.model.primitives.TagKey.Type
    object TagValue extends Subtype[String]
    type TagValue = zio.aws.proton.model.primitives.TagValue.Type
    object TemplateFileContents extends Subtype[String]
    type TemplateFileContents =
      zio.aws.proton.model.primitives.TemplateFileContents.Type
    object TemplateManifestContents extends Subtype[String]
    type TemplateManifestContents =
      zio.aws.proton.model.primitives.TemplateManifestContents.Type
    object TemplateSchema extends Subtype[String]
    type TemplateSchema = zio.aws.proton.model.primitives.TemplateSchema.Type
    object TemplateVersionPart extends Subtype[String]
    type TemplateVersionPart =
      zio.aws.proton.model.primitives.TemplateVersionPart.Type
    object Timestamp extends Subtype[Instant]
    type Timestamp = zio.aws.proton.model.primitives.Timestamp.Type
  }
  type CompatibleEnvironmentTemplateInputList =
    List[zio.aws.proton.model.CompatibleEnvironmentTemplateInput]
  type CompatibleEnvironmentTemplateList =
    List[zio.aws.proton.model.CompatibleEnvironmentTemplate]
  type ComponentSummaryList = List[zio.aws.proton.model.ComponentSummary]
  type EnvironmentAccountConnectionStatusList =
    List[zio.aws.proton.model.EnvironmentAccountConnectionStatus]
  type EnvironmentAccountConnectionSummaryList =
    List[zio.aws.proton.model.EnvironmentAccountConnectionSummary]
  type EnvironmentSummaryList = List[zio.aws.proton.model.EnvironmentSummary]
  type EnvironmentTemplateFilterList =
    List[zio.aws.proton.model.EnvironmentTemplateFilter]
  type EnvironmentTemplateSummaryList =
    List[zio.aws.proton.model.EnvironmentTemplateSummary]
  type EnvironmentTemplateVersionSummaryList =
    List[zio.aws.proton.model.EnvironmentTemplateVersionSummary]
  type LatestSyncBlockers = List[zio.aws.proton.model.SyncBlocker]
  type ListServiceInstancesFilterList =
    List[zio.aws.proton.model.ListServiceInstancesFilter]
  type NotifyResourceDeploymentStatusChangeInputOutputsList =
    List[zio.aws.proton.model.Output]
  type OutputsList = List[zio.aws.proton.model.Output]
  type ProvisionedResourceList = List[zio.aws.proton.model.ProvisionedResource]
  type RepositorySummaryList = List[zio.aws.proton.model.RepositorySummary]
  type RepositorySyncDefinitionList =
    List[zio.aws.proton.model.RepositorySyncDefinition]
  type RepositorySyncEvents = List[zio.aws.proton.model.RepositorySyncEvent]
  type ResourceSyncEvents = List[zio.aws.proton.model.ResourceSyncEvent]
  type ServiceInstanceSummaryList =
    List[zio.aws.proton.model.ServiceInstanceSummary]
  type ServiceSummaryList = List[zio.aws.proton.model.ServiceSummary]
  type ServiceTemplateSummaryList =
    List[zio.aws.proton.model.ServiceTemplateSummary]
  type ServiceTemplateSupportedComponentSourceInputList =
    List[zio.aws.proton.model.ServiceTemplateSupportedComponentSourceType]
  type ServiceTemplateVersionSummaryList =
    List[zio.aws.proton.model.ServiceTemplateVersionSummary]
  type SyncBlockerContexts = List[zio.aws.proton.model.SyncBlockerContext]
  type TagKeyList = List[TagKey]
  type TagList = List[zio.aws.proton.model.Tag]
}
